@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+from polyaxon import pkg
 from polyaxon.containers.names import MAIN_JOB_CONTAINER
 from polyaxon.containers.pull_policy import PullPolicy
 from polyaxon.k8s import k8s_schemas
@@ -23,16 +23,16 @@ from polyaxon.k8s.k8s_schemas import V1Container
 def get_default_notification_container():
     return V1Container(
         name=MAIN_JOB_CONTAINER,
-        image="polyaxon/polyaxon-events-handlers:{}".format("dev"),
-        image_pull_policy=PullPolicy.ALWAYS.value,
+        image="polyaxon/polyaxon-events-handlers:{}".format(pkg.VERSION),
+        image_pull_policy=PullPolicy.IF_NOT_PRESENT.value,
         command=["polyaxon", "notify"],
         args=[
             "--kind={{kind}}",
             "--owner={{owner}}",
             "--project={{project}}",
             "--run-uuid={{run_uuid}}",
-            "--run-name={{run_name}}",
-            "--condition={{condition}}",
+            "{{params.condition.as_arg}}",
+            "{{params.run_name.as_arg}}",
         ],
         resources=k8s_schemas.V1ResourceRequirements(
             limits={"cpu": "0.5", "memory": "100Mi"},
