@@ -20,12 +20,13 @@ import click
 
 from polyaxon.cli.dashboard import get_dashboard, get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.managers.deploy import DeployManager
+from polyaxon.logger import clean_outputs
+from polyaxon.managers.deploy import DeployConfigManager
 from polyaxon.utils.formatting import Printer
 from polyaxon.utils.list_utils import to_list
 
 
-def read_deployment_config(filepaths):
+def read_deployment_config(filepaths, command: str):
     from polyaxon.deploy import reader
 
     if not filepaths:
@@ -35,7 +36,9 @@ def read_deployment_config(filepaths):
     for filepath in filepaths:
         if not os.path.isfile(filepath):
             Printer.print_error(
-                "`{}` must be a valid file".format(filepath), sys_exit=True
+                "`{}` must be a valid file".format(filepath),
+                sys_exit=True,
+                command_help="admin {}".format(command),
             )
     try:
         deployment_config = reader.read(filepaths)
@@ -47,6 +50,7 @@ def read_deployment_config(filepaths):
 
 
 @click.group()
+@clean_outputs
 def admin():
     """Commands for admin management."""
 
@@ -60,7 +64,9 @@ def admin():
     help="The polyaxon deployment config file(s) to check.",
 )
 @click.option(
-    "-t", "--deployment-type", help="Deployment type.",
+    "-t",
+    "--deployment-type",
+    help="Deployment type.",
 )
 @click.option(
     "--manager-path",
@@ -79,10 +85,11 @@ def admin():
     default=False,
     help="Dry run the configuration and generate a debuggable output.",
 )
+@clean_outputs
 def deploy(config_file, deployment_type, manager_path, check, dry_run):
     """Deploy polyaxon."""
-    config = read_deployment_config(config_file)
-    manager = DeployManager(
+    config = read_deployment_config(config_file, command="deploy")
+    manager = DeployConfigManager(
         config=config,
         filepath=config_file,
         deployment_type=deployment_type,
@@ -122,7 +129,9 @@ def deploy(config_file, deployment_type, manager_path, check, dry_run):
     help="The polyaxon deployment config file(s) to check.",
 )
 @click.option(
-    "-t", "--deployment-type", help="Deployment type.",
+    "-t",
+    "--deployment-type",
+    help="Deployment type.",
 )
 @click.option(
     "--manager-path",
@@ -141,10 +150,11 @@ def deploy(config_file, deployment_type, manager_path, check, dry_run):
     default=False,
     help="Dry run the configuration and generate a debuggable output.",
 )
+@clean_outputs
 def upgrade(config_file, deployment_type, manager_path, check, dry_run):
     """Upgrade a Polyaxon deployment."""
-    config = read_deployment_config(config_file)
-    manager = DeployManager(
+    config = read_deployment_config(config_file, command="upgrade")
+    manager = DeployConfigManager(
         config=config,
         filepath=config_file,
         deployment_type=deployment_type,
@@ -187,10 +197,11 @@ def upgrade(config_file, deployment_type, manager_path, check, dry_run):
     type=click.Path(exists=True),
     help="The path of the deployment manager, e.g. local chart.",
 )
+@clean_outputs
 def teardown(config_file, manager_path):
     """Teardown a polyaxon deployment given a config file."""
-    config = read_deployment_config(config_file)
-    manager = DeployManager(
+    config = read_deployment_config(config_file, command="teardown")
+    manager = DeployConfigManager(
         config=config, filepath=config_file, manager_path=manager_path
     )
     exception = None
@@ -219,6 +230,7 @@ def teardown(config_file, manager_path):
 @click.option(
     "--url", is_flag=True, default=False, help="Print the url of the dashboard."
 )
+@clean_outputs
 def dashboard(yes, url):
     """Open dashboard in browser."""
     get_dashboard(dashboard_url=get_dashboard_url(base="_admin"), url_only=url, yes=yes)
