@@ -22,23 +22,29 @@ import polyaxon_sdk
 from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
-from polyaxon.cli.errors import handle_cli_error
+from polyaxon import settings
+from polyaxon.cli.dashboard import get_dashboard_url
+from polyaxon.cli.errors import handle_cli_error, handle_command_not_in_ce
 from polyaxon.cli.session import session_expired, set_versions_config
 from polyaxon.client import PolyaxonClient
-from polyaxon.logger import logger
+from polyaxon.logger import clean_outputs, logger
 from polyaxon.managers.auth import AuthConfigManager
 from polyaxon.managers.cli import CliConfigManager
+from polyaxon.managers.user import UserConfigManager
 from polyaxon.schemas.api.authentication import AccessTokenConfig, V1Credentials
 from polyaxon.utils.formatting import Printer, dict_tabulate, dict_to_tabulate
-from polyaxon.utils.http_utils import polyaxon_ui
 
 
 @click.command()
 @click.option("--token", "-t", help="Polyaxon token.")
 @click.option("--username", "-u", help="Polyaxon username or email.")
 @click.option("--password", "-p", help="Polyaxon password.")
+@clean_outputs
 def login(token, username, password):
-    """Login to Polyaxon."""
+    """Login to Polyaxon Cloud or Polyaxon EE."""
+    if not settings.CLI_CONFIG or settings.CLI_CONFIG.is_ce:
+        handle_command_not_in_ce()
+
     polyaxon_client = PolyaxonClient()
     if username and not token:
         # Use user or email / password login
@@ -59,6 +65,7 @@ def login(token, username, password):
             access_auth = polyaxon_client.auth_v1.login(body=body)
         except (ApiException, HTTPError) as e:
             AuthConfigManager.purge()
+            UserConfigManager.purge()
             CliConfigManager.purge()
             handle_cli_error(e, message="Could not login.")
             sys.exit(1)
@@ -68,9 +75,7 @@ def login(token, username, password):
             return
     else:
         if not token:
-            token_url = "{}/profile/token".format(
-                polyaxon_ui(polyaxon_client.config.host)
-            )
+            token_url = get_dashboard_url(subpath="profile/token")
             click.confirm(
                 "Authentication token page will now open in your browser. Continue?",
                 abort=True,
@@ -100,6 +105,7 @@ def login(token, username, password):
     # Set user
     try:
         AuthConfigManager.purge()
+        UserConfigManager.purge()
         polyaxon_client = PolyaxonClient(token=access_auth.token)
         user = polyaxon_client.users_v1.get_user()
     except (ApiException, HTTPError) as e:
@@ -107,6 +113,7 @@ def login(token, username, password):
         sys.exit(1)
     access_token = AccessTokenConfig(username=user.username, token=access_auth.token)
     AuthConfigManager.set_config(access_token)
+    UserConfigManager.set_config(user)
     polyaxon_client.config.token = access_auth.token
     Printer.print_success("Login successful")
 
@@ -114,16 +121,22 @@ def login(token, username, password):
 
 
 @click.command()
+@clean_outputs
 def logout():
-    """Logout of Polyaxon."""
+    """Logout from Polyaxon Cloud or Polyaxon EE."""
     AuthConfigManager.purge()
+    UserConfigManager.purge()
     CliConfigManager.purge()
     Printer.print_success("You are logged out")
 
 
 @click.command()
+@clean_outputs
 def whoami():
-    """Show current logged Polyaxon user."""
+    """Show current logged Polyaxon Cloud or Polyaxon EE user."""
+    if not settings.CLI_CONFIG or settings.CLI_CONFIG.is_ce:
+        handle_command_not_in_ce()
+
     try:
         polyaxon_client = PolyaxonClient()
         user = polyaxon_client.users_v1.get_user()
@@ -134,6 +147,6 @@ def whoami():
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not load user info.", sys_exit=True)
 
-    response = dict_to_tabulate(user.to_dict(), exclude_attrs=["role"])
+    response = dict_to_tabulate(user.to_dict(), exclude_attrs=["role", "theme"])
     Printer.print_header("User info:")
     dict_tabulate(response)
