@@ -24,25 +24,54 @@ from urllib3.exceptions import HTTPError
 from polyaxon.api import REWRITE_SERVICES_V1, SERVICES_V1
 from polyaxon.cli.dashboard import get_dashboard, get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
+from polyaxon.cli.options import OPTIONS_PROJECT, OPTIONS_RUN_UID
 from polyaxon.client import RunClient
 from polyaxon.client.run import get_run_logs
-from polyaxon.config_reader.spec import ConfigSpec
 from polyaxon.env_vars.getters import get_project_or_local, get_project_run_or_local
-from polyaxon.exceptions import PolyaxonClientException
+from polyaxon.exceptions import (
+    PolyaxonClientException,
+    PolyaxonHTTPError,
+    PolyaxonShouldExitError,
+)
 from polyaxon.lifecycle import LifeCycle, V1Statuses
-from polyaxon.managers.run import RunManager
+from polyaxon.logger import clean_outputs
+from polyaxon.managers.ignore import IgnoreConfigManager
+from polyaxon.managers.run import RunConfigManager
+from polyaxon.metadata.keys import META_REWRITE_PATH
+from polyaxon.polyaxonfile import OperationSpecification
 from polyaxon.polyflow import V1RunKind
 from polyaxon.utils import cache
+from polyaxon.utils.csv_utils import write_csv
 from polyaxon.utils.formatting import (
     Printer,
     dict_tabulate,
     dict_to_tabulate,
+    flatten_keys,
     get_meta_response,
-    get_runs_with_keys,
+    list_dicts_to_csv,
     list_dicts_to_tabulate,
 )
 from polyaxon.utils.validation import validate_tags
 
+DEFAULT_EXCLUDE = [
+    "owner",
+    "project",
+    "description",
+    "content",
+    "raw_content",
+    "live_state",
+    "readme",
+    "settings",
+    "meta_info",
+    "is_approved",
+    "is_managed",
+    "schedule_at",
+    "original",
+    "pipeline",
+    "role",
+    "status_conditions",
+]
+
 
 def get_run_details(run):  # pylint:disable=redefined-outer-name
     if run.description:
@@ -57,6 +86,14 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
         Printer.print_header("Run outputs:")
         dict_tabulate(run.outputs)
 
+    if run.settings:
+        Printer.print_header("Run settings:")
+        dict_tabulate(run.settings.to_dict())
+
+    if run.meta_info:
+        Printer.print_header("Run meta info:")
+        dict_tabulate(run.meta_info)
+
     response = Printer.add_status_color(run.to_dict())
     response = dict_to_tabulate(
         response,
@@ -70,6 +107,9 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
             "inputs",
             "outputs",
             "is_managed",
+            "status_conditions",
+            "settings",
+            "meta_info",
         ],
     )
 
@@ -78,37 +118,48 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
 
 
 @click.group()
-@click.option(
-    "--project", "-p", type=str, help="The project name, e.g. 'mnist' or 'adam/mnist'."
-)
-@click.option("--uid", "-uid", type=str, help="The run uuid.")
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.pass_context
+@clean_outputs
 def ops(ctx, project, uid):
     """Commands for ops/runs."""
     ctx.obj = ctx.obj or {}
+    if project or uid:
+        Printer.print_warning(
+            "Passing arguments to command groups is deprecated and will be removed in v1.2! "
+            "Please use arguments on the sub-command directly: `polyaxon ops SUB_COMMAND --help`"
+        )
     ctx.obj["project"] = project
     if ctx.invoked_subcommand not in ["ls"]:
         ctx.obj["run_uuid"] = uid
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(
     "--io",
     "-io",
     is_flag=True,
     help="List runs with their inputs/outputs (params, metrics, results, ...).",
 )
+@click.option(
+    "--to-csv",
+    is_flag=True,
+    help="Saves the results to a csv file. Note that this flag requires pandas",
+)
 @click.option(
     "--query", "-q", type=str, help="To filter the runs based on this query spec."
 )
 @click.option(
     "--sort", "-s", type=str, help="To order the runs based on this sort spec."
 )
-@click.option("--limit", type=int, help="To limit the list of runs.")
-@click.option("--offset", type=int, help="To offset the list of runs.")
+@click.option("--limit", "-l", type=int, help="To limit the list of runs.")
+@click.option("--offset", "-off", type=int, help="To offset the list of runs.")
 @click.option("--columns", "-c", type=str, help="The columns to show.")
 @click.pass_context
-def ls(ctx, io, query, sort, limit, offset, columns):
+@clean_outputs
+def ls(ctx, project, io, to_csv, query, sort, limit, offset, columns):
     """List runs for this project.
 
     Uses /docs/core/cli/#caching
@@ -144,7 +195,9 @@ def ls(ctx, io, query, sort, limit, offset, columns):
     \b
     $ polyaxon ops ls -q "kind: service"
     """
-    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    owner, project_name = get_project_or_local(
+        project or ctx.obj.get("project"), is_cli=True
+    )
 
     try:
         polyaxon_client = RunClient(owner=owner, project=project_name)
@@ -168,61 +221,61 @@ def ls(ctx, io, query, sort, limit, offset, columns):
         )
 
     objects = [Printer.add_status_color(o.to_dict()) for o in response.results]
-
+    columns = validate_tags(columns)
     if io:
-        objects = get_runs_with_keys(objects=objects, params_keys=["inputs", "outputs"])
-        objects = list_dicts_to_tabulate(
-            objects,
-            include_attrs=validate_tags(columns),
-            exclude_attrs=[
-                "owner",
-                "project",
-                "description",
-                "content",
-                "raw_content",
-                "deleted",
-                "readme",
-                "settings",
-                "meta_info",
-                "original",
-                "pipeline",
-                "role",
-                "status_conditions",
-                "is_helper",
-            ],
+        objects, prefixed_columns = flatten_keys(
+            objects=objects,
+            columns=["inputs", "outputs"],
+            columns_prefix={"inputs": "in", "outputs": "out"},
         )
+        if columns:
+            columns = {prefixed_columns.get(col, col) for col in columns}
+        if to_csv:
+            objects = list_dicts_to_csv(
+                objects,
+                include_attrs=columns,
+                exclude_attrs=DEFAULT_EXCLUDE,
+            )
+        else:
+            objects = list_dicts_to_tabulate(
+                objects,
+                include_attrs=columns,
+                exclude_attrs=DEFAULT_EXCLUDE,
+                humanize_values=True,
+                upper_keys=True,
+            )
     else:
-        objects = list_dicts_to_tabulate(
-            objects,
-            include_attrs=validate_tags(columns),
-            exclude_attrs=[
-                "owner",
-                "project",
-                "description",
-                "content",
-                "raw_content",
-                "deleted",
-                "readme",
-                "inputs",
-                "outputs",
-                "settings",
-                "meta_info",
-                "original",
-                "pipeline",
-                "role",
-                "status_conditions",
-                "is_helper",
-            ],
-        )
+        if to_csv:
+            objects = list_dicts_to_csv(
+                objects,
+                include_attrs=columns,
+                exclude_attrs=DEFAULT_EXCLUDE + ["inputs", "outputs"],
+            )
+        else:
+            objects = list_dicts_to_tabulate(
+                objects,
+                include_attrs=columns,
+                exclude_attrs=DEFAULT_EXCLUDE + ["inputs", "outputs"],
+                humanize_values=True,
+                upper_keys=True,
+            )
     if objects:
-        Printer.print_header("Runs:")
-        objects.pop("project_name", None)
-        dict_tabulate(objects, is_list_dict=True)
+        if to_csv:
+            filename = "./results.csv"
+            write_csv(objects, filename=filename)
+            Printer.print_success("CSV file generated: `{}`".format(filename))
+        else:
+            Printer.print_header("Runs:")
+            objects.pop("project_name", None)
+            dict_tabulate(objects, is_list_dict=True)
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.pass_context
-def get(ctx):
+@clean_outputs
+def get(ctx, project, uid):
     """Get run.
 
     Uses /docs/core/cli/#caching
@@ -233,17 +286,19 @@ def get(ctx):
     $ polyaxon ops get  # if run is cached
 
     \b
-    $ polyaxon ops --uid=8aac02e3a62a4f0aaa257c59da5eab80 get  # project is cached
+    $ polyaxon ops get --uid=8aac02e3a62a4f0aaa257c59da5eab80 # project is cached
 
     \b
-    $ polyaxon ops --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80 get
+    $ polyaxon ops get --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80
 
     \b
-    $ polyaxon ops -p alain/cats-vs-dogs --uid=8aac02e3a62a4f0aaa257c59da5eab80 get
+    $ polyaxon ops get -p alain/cats-vs-dogs --uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
 
     try:
@@ -255,18 +310,29 @@ def get(ctx):
             polyaxon_client.run_data
         )
         cache.cache(
-            config_manager=RunManager, config=config, owner=owner, project=project_name
+            config_manager=RunConfigManager,
+            config=config,
+            owner=owner,
+            project=project_name,
         )
     except (ApiException, HTTPError) as e:
-        handle_cli_error(e, message="Could not load run `{}` info.".format(run_uuid))
+        handle_cli_error(
+            e,
+            message="Could not load run `{}/{}/{}` info.".format(
+                owner, project_name, run_uuid
+            ),
+        )
         sys.exit(1)
 
     get_run_details(polyaxon_client.run_data)
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.pass_context
-def delete(ctx):
+@clean_outputs
+def delete(ctx, project, uid):
     """Delete a run.
 
     Uses /docs/core/cli/#caching
@@ -277,13 +343,15 @@ def delete(ctx):
     $ polyaxon ops delete
 
     \b
-    $ polyaxon ops --uid=8aac02e3a62a4f0aaa257c59da5eab80 delete  # project is cached
+    $ polyaxon ops delete --uid=8aac02e3a62a4f0aaa257c59da5eab80  # project is cached
 
     \b
-    $ polyaxon ops --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80 delete
+    $ polyaxon ops delete --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80
     """
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     if not click.confirm("Are sure you want to delete run `{}`".format(run_uuid)):
         click.echo("Existing without deleting the run.")
@@ -295,7 +363,7 @@ def delete(ctx):
         )
         polyaxon_client.delete()
         # Purge caching
-        RunManager.purge()
+        RunConfigManager.purge()
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not delete run `{}`.".format(run_uuid))
         sys.exit(1)
@@ -304,13 +372,16 @@ def delete(ctx):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option("--name", type=str, help="Name of the run (optional).")
 @click.option("--description", type=str, help="Description of the run (optional).")
 @click.option(
     "--tags", type=str, help="Tags of the run, comma separated values (optional)."
 )
 @click.pass_context
-def update(ctx, name, description, tags):
+@clean_outputs
+def update(ctx, project, uid, name, description, tags):
     """Update run.
 
     Uses /docs/core/cli/#caching
@@ -318,15 +389,17 @@ def update(ctx, name, description, tags):
     Examples:
 
     \b
-    $ polyaxon ops --uid=8aac02e3a62a4f0aaa257c59da5eab80 update
+    $ polyaxon ops  update --uid=8aac02e3a62a4f0aaa257c59da5eab80
     --description="new description for my runs"
 
     \b
-    $ polyaxon ops --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80 update
+    $ polyaxon ops  update --project=cats-vs-dogs -uid 8aac02e3a62a4f0aaa257c59da5eab80
     --tags="foo, bar" --name="unique-name"
     """
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     update_dict = {}
 
@@ -358,6 +431,44 @@ def update(ctx, name, description, tags):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.pass_context
+@clean_outputs
+def approve(ctx, project, uid):
+    """Approve a run waiting for human validation.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops approve
+
+    \b
+    $ polyaxon ops approve --uid=8aac02e3a62a4f0aaa257c59da5eab80
+    """
+    owner, project_name, run_uuid = get_project_run_or_local(
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
+    )
+
+    try:
+        polyaxon_client = RunClient(
+            owner=owner, project=project_name, run_uuid=run_uuid
+        )
+        polyaxon_client.approve()
+    except (ApiException, HTTPError) as e:
+        handle_cli_error(e, message="Could not approve run `{}`.".format(run_uuid))
+        sys.exit(1)
+
+    Printer.print_success("Run is approved.")
+
+
+@ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "--yes",
     "-y",
@@ -367,7 +478,8 @@ def update(ctx, name, description, tags):
     'Assume "yes" as answer to all prompts and run non-interactively.',
 )
 @click.pass_context
-def stop(ctx, yes):
+@clean_outputs
+def stop(ctx, project, uid, yes):
     """Stop run.
 
     Uses /docs/core/cli/#caching
@@ -378,10 +490,12 @@ def stop(ctx, yes):
     $ polyaxon ops stop
 
     \b
-    $ polyaxon ops --uid=8aac02e3a62a4f0aaa257c59da5eab80 stop
+    $ polyaxon ops stop --uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     if not yes and not click.confirm(
         "Are sure you want to stop " "run `{}`".format(run_uuid)
@@ -402,6 +516,8 @@ def stop(ctx, yes):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "--copy",
     "-c",
@@ -415,10 +531,11 @@ def stop(ctx, yes):
     "polyaxonfile",
     multiple=True,
     type=click.Path(exists=True),
-    help="The polyaxonfiles to update with.",
+    help="The polyaxonfiles to update with, they should be an operation preset.",
 )
 @click.pass_context
-def restart(ctx, copy, polyaxonfile):
+@clean_outputs
+def restart(ctx, project, uid, copy, polyaxonfile):
     """Restart run.
 
     Uses /docs/core/cli/#caching
@@ -430,10 +547,14 @@ def restart(ctx, copy, polyaxonfile):
     """
     content = None
     if polyaxonfile:
-        content = "{}".format(ConfigSpec.read_from(polyaxonfile))
+        content = OperationSpecification.read(polyaxonfile, is_preset=True).to_dict(
+            dump=True
+        )
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     try:
         polyaxon_client = RunClient(
@@ -451,16 +572,19 @@ def restart(ctx, copy, polyaxonfile):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "-f",
     "--file",
     "polyaxonfile",
     multiple=True,
     type=click.Path(exists=True),
-    help="The polyaxonfiles to update with.",
+    help="The polyaxonfiles to update with, they should be an operation preset.",
 )
 @click.pass_context
-def resume(ctx, polyaxonfile):
+@clean_outputs
+def resume(ctx, project, uid, polyaxonfile):
     """Resume run.
 
     Uses /docs/core/cli/#caching
@@ -468,14 +592,18 @@ def resume(ctx, polyaxonfile):
     Examples:
 
     \b
-    $ polyaxon ops --uid=8aac02e3a62a4f0aaa257c59da5eab80 resume
+    $ polyaxon ops resume --uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
     content = None
     if polyaxonfile:
-        content = "{}".format(ConfigSpec.read_from(polyaxonfile))
+        content = OperationSpecification.read(polyaxonfile, is_preset=True).to_dict(
+            dump=True
+        )
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     try:
         polyaxon_client = RunClient(
@@ -489,8 +617,11 @@ def resume(ctx, polyaxonfile):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.pass_context
-def invalidate(ctx):
+@clean_outputs
+def invalidate(ctx, project, uid):
     """Invalidate the run's cache state.
 
     Uses /docs/core/cli/#caching
@@ -502,7 +633,9 @@ def invalidate(ctx):
     """
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     try:
         polyaxon_client = RunClient(
@@ -516,9 +649,12 @@ def invalidate(ctx):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option("--watch", "-w", is_flag=True, help="Watch statuses.")
 @click.pass_context
-def statuses(ctx, watch):
+@clean_outputs
+def statuses(ctx, project, uid, watch):
     """Get run or run job statuses.
 
     Uses /docs/core/cli/#caching
@@ -529,7 +665,7 @@ def statuses(ctx, watch):
     $ polyaxon ops statuses
 
     \b
-    $ polyaxon ops -uid=8aac02e3a62a4f0aaa257c59da5eab80 statuses
+    $ polyaxon ops statuses -uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
 
     def _handle_run_statuses():
@@ -552,7 +688,9 @@ def statuses(ctx, watch):
             dict_tabulate(objects, is_list_dict=True)
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
 
     client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
@@ -587,12 +725,12 @@ def statuses(ctx, watch):
 #     Examples for getting run resources:
 #
 #     \b
-#     $ polyaxon ops -uid=8aac02e3a62a4f0aaa257c59da5eab80 resources
+#     $ polyaxon ops resources -uid=8aac02e3a62a4f0aaa257c59da5eab80
 #
 #     For GPU resources
 #
 #     \b
-#     $ polyaxon ops -uid=8aac02e3a62a4f0aaa257c59da5eab80 resources --gpu
+#     $ polyaxon ops resources -uid=8aac02e3a62a4f0aaa257c59da5eab80 --gpu
 #     """
 #
 #     def get_run_resources():
@@ -615,6 +753,8 @@ def statuses(ctx, watch):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "--follow",
     "-f",
@@ -630,14 +770,21 @@ def statuses(ctx, watch):
     help="Whether or not to hide timestamps from the log stream.",
 )
 @click.option(
-    "--all-info",
-    "-a",
+    "--all-containers",
     is_flag=True,
     default=False,
     help="Whether to stream logs from all containers.",
 )
+@click.option(
+    "--all-info",
+    "-a",
+    is_flag=True,
+    default=False,
+    help="Whether to show all information including container names, pod names, and node names.",
+)
 @click.pass_context
-def logs(ctx, follow, hide_time, all_info):
+@clean_outputs
+def logs(ctx, project, uid, follow, hide_time, all_containers, all_info):
     """Get run or run job logs.
 
     Uses /docs/core/cli/#caching
@@ -648,28 +795,54 @@ def logs(ctx, follow, hide_time, all_info):
     $ polyaxon run logs
 
     \b
-    $ polyaxon ops -uid=8aac02e3a62a4f0aaa257c59da5eab80 -p mnist logs
+    $ polyaxon ops logs -uid=8aac02e3a62a4f0aaa257c59da5eab80 -p mnist
     """
 
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
 
     try:
         get_run_logs(
-            client=client, hide_time=hide_time, all_info=all_info, follow=follow,
+            client=client,
+            hide_time=hide_time,
+            all_containers=all_containers,
+            all_info=all_info,
+            follow=follow,
         )
     except (ApiException, HTTPError, PolyaxonClientException) as e:
         handle_cli_error(
-            e, message="Could not get logs for run `{}`.".format(client.run_uuid),
+            e,
+            message="Could not get logs for run `{}`.".format(client.run_uuid),
         )
         sys.exit(1)
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--path",
+    type=str,
+    help="Path to download, if not provided the full run's  artifacts will downloaded.",
+)
+@click.option(
+    "--path-to",
+    type=click.Path(exists=False),
+    help="The destination where to download the artifacts.",
+)
+@click.option(
+    "--no-untar",
+    is_flag=True,
+    default=False,
+    help="Disable the automatic untar of the downloaded the artifacts.",
+)
 @click.pass_context
-def artifacts(ctx):
+@clean_outputs
+def artifacts(ctx, project, uid, path, path_to, no_untar):
     """Download outputs/artifacts for run.
 
     Uses /docs/core/cli/#caching
@@ -677,23 +850,118 @@ def artifacts(ctx):
     Examples:
 
     \b
-    $ polyaxon ops -uid=8aac02e3a62a4f0aaa257c59da5eab80 artifacts
+    $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80
+
+    \b
+    $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80 path="events/only"
+
+    \b
+    $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_to="this/path"
     """
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     try:
         client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
-        client.download_artifacts()
+        download_path = client.download_artifacts(
+            path=path or "", path_to=path_to, untar=not no_untar
+        )
     except (ApiException, HTTPError) as e:
         handle_cli_error(
             e, message="Could not download outputs for run `{}`.".format(run_uuid)
         )
         sys.exit(1)
-    Printer.print_success("Files downloaded.")
+    Printer.print_success("Files downloaded: path: {}".format(download_path))
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--path-from",
+    type=click.Path(exists=False),
+    help="Path to use to upload. Defaults to current path.",
+)
+@click.option(
+    "--path-to",
+    type=str,
+    help="The destination where to upload the artifacts. If run's root artifacts path will be used.",
+)
+@click.option(
+    "--is-file",
+    is_flag=True,
+    default=False,
+    help="If the content is a single file.",
+)
+@click.option(
+    "--sync-failure",
+    is_flag=True,
+    default=False,
+    help="To set the run to failed if upload fails.",
+)
+@click.pass_context
+@clean_outputs
+def upload(ctx, project, uid, path_from, path_to, is_file, sync_failure):
+    """Upload runs' artifacts.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80
+
+    \b
+    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_from="path/to/upload"
+
+    \b
+    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_to="path/to/upload/to"
+    """
+    owner, project_name, run_uuid = get_project_run_or_local(
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
+    )
+    try:
+        client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
+        if is_file:
+            response = client.upload_artifact(
+                filepath=path_from, path=path_to or "", overwrite=True
+            )
+        else:
+            files = IgnoreConfigManager.get_unignored_filepaths(path_from)
+            response = client.upload_artifacts(
+                files=files, path=path_to or "", overwrite=True, relative_to=path_from
+            )
+    except (
+        ApiException,
+        HTTPError,
+        PolyaxonHTTPError,
+        PolyaxonShouldExitError,
+        PolyaxonClientException,
+    ) as e:
+        handle_cli_error(
+            e, message="Could not upload artifacts for run `{}`.".format(run_uuid)
+        )
+        sys.exit(1)
+
+    if response.status_code == 200:
+        Printer.print_success("Artifacts uploaded.")
+    else:
+        if sync_failure:
+            client.log_failed(message="Operation failed uploading artifacts.")
+        Printer.print_error(
+            "Error uploading artifacts. "
+            "Status: {}. Error: {}.".format(response.status_code, response.content),
+            sys_exit=True,
+        )
+
+
+@ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "--yes",
     "-y",
@@ -709,10 +977,13 @@ def artifacts(ctx):
     help="Print the url of the dashboard for this run.",
 )
 @click.pass_context
-def dashboard(ctx, yes, url):
+@clean_outputs
+def dashboard(ctx, project, uid, yes, url):
     """Open this operation's dashboard details in browser."""
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     subpath = "{}/{}/runs/{}".format(owner, project_name, run_uuid)
     get_dashboard(
@@ -721,6 +992,8 @@ def dashboard(ctx, yes, url):
 
 
 @ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(
     "--yes",
     "-y",
@@ -730,7 +1003,10 @@ def dashboard(ctx, yes, url):
     'Assume "yes" as answer to all prompts and run non-interactively.',
 )
 @click.option(
-    "--external", is_flag=True, default=False, help="Open the external service URL.",
+    "--external",
+    is_flag=True,
+    default=False,
+    help="Open the external service URL.",
 )
 @click.option(
     "--url",
@@ -739,7 +1015,8 @@ def dashboard(ctx, yes, url):
     help="Print the url of the dashboard or external service.",
 )
 @click.pass_context
-def service(ctx, yes, external, url):
+@clean_outputs
+def service(ctx, project, uid, yes, external, url):
     """Open the operation service in browser.
 
     N.B. The operation must have a run kind service, otherwise it will raise an error.
@@ -748,7 +1025,9 @@ def service(ctx, yes, external, url):
     please use the `--external` flag.
     """
     owner, project_name, run_uuid = get_project_run_or_local(
-        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
     )
     client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
     client.refresh_data()
@@ -778,7 +1057,7 @@ def service(ctx, yes, external, url):
 
     namespace = client.run_data.settings.namespace
     service_endpoint = SERVICES_V1
-    if client.run_data.meta_info.get("rewrite_path", False):
+    if client.run_data.meta_info.get(META_REWRITE_PATH, False):
         service_endpoint = REWRITE_SERVICES_V1
     external_run_url = get_dashboard_url(
         base=service_endpoint,
