@@ -20,7 +20,11 @@ import click
 from polyaxon import settings
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.deploy.schemas.deployment_types import DeploymentTypes
+from polyaxon.logger import clean_outputs
+from polyaxon.managers.auth import AuthConfigManager
+from polyaxon.managers.cli import CliConfigManager
 from polyaxon.managers.client import ClientConfigManager
+from polyaxon.managers.user import UserConfigManager
 from polyaxon.utils.formatting import Printer
 
 
@@ -35,7 +39,9 @@ from polyaxon.utils.formatting import Printer
     help="The namespace used for deploying Polyaxon, default polyaxon.",
 )
 @click.option(
-    "-t", "--deployment-type", help="Deployment type.",
+    "-t",
+    "--deployment-type",
+    help="Deployment type.",
 )
 @click.option(
     "-r",
@@ -43,6 +49,7 @@ from polyaxon.utils.formatting import Printer
     type=str,
     help="The release name used for deploying Polyaxon, default polyaxon.",
 )
+@clean_outputs
 def port_forward(port, namespace, deployment_type, release_name):
     """If you deploy Polyaxon using ClusterIP, you can use this command
     to access the gateway through `localhost:port`.
@@ -78,6 +85,9 @@ def port_forward(port, namespace, deployment_type, release_name):
 
     _config.host = "http://localhost:{}".format(port)
     ClientConfigManager.set_config(_config)
+    CliConfigManager.purge()
+    AuthConfigManager.purge()
+    UserConfigManager.purge()
     Printer.print_header("Client configuration is updated!")
     Printer.print_success("Polyaxon will be available at: {}".format(_config.host))
     stdout = kubectl.execute(
