@@ -17,11 +17,11 @@
 import polyaxon_sdk
 
 from polyaxon import settings
-from polyaxon.client.transport import Transport
+from polyaxon.constants import NO_AUTH
 
 
 class PolyaxonClient:
-    """Auto-configurable and high level base client that abstract
+    """Auto-configurable and high-level base client that abstract
     the need to set a configuration for each service.
 
     PolyaxonClient comes with logic
@@ -54,15 +54,18 @@ class PolyaxonClient:
     >>> client.auth_v1
     >>> client.users_v1
     >>> client.agents_v1
-    >>> client.components_v1
-    >>> client.models_v1
+    >>> client.component_hub_v1
+    >>> client.model_registry_v1
     ```
     """
 
     def __init__(self, config=None, token=None):
 
         self._config = config or settings.CLIENT_CONFIG
-        self._config.token = token or settings.AUTH_CONFIG.token
+        if not token:
+            self._config.token = settings.AUTH_CONFIG.token
+        elif token != NO_AUTH:
+            self._config.token = token
 
         self._transport = None
         self.api_client = polyaxon_sdk.ApiClient(
@@ -74,8 +77,8 @@ class PolyaxonClient:
         self._users_v1 = None
         self._versions_v1 = None
         self._agents_v1 = None
-        self._components_v1 = None
-        self._models_v1 = None
+        self._component_hub_v1 = None
+        self._model_registry_v1 = None
 
     def reset(self):
         self._transport = None
@@ -85,24 +88,12 @@ class PolyaxonClient:
         self._users_v1 = None
         self._versions_v1 = None
         self._agents_v1 = None
-        self._components_v1 = None
-        self._models_v1 = None
+        self._component_hub_v1 = None
+        self._model_registry_v1 = None
         self.api_client = polyaxon_sdk.ApiClient(
             self.config.sdk_config, **self.config.client_header
         )
 
-    def set_health_check(self, url):
-        self.transport.set_health_check(url)
-
-    def unset_health_check(self, url):
-        self.transport.unset_health_check(url)
-
-    @property
-    def transport(self):
-        if not self._transport:
-            self._transport = Transport(config=self.config)
-        return self._transport
-
     @property
     def config(self):
         return self._config
@@ -144,16 +135,16 @@ class PolyaxonClient:
         return self._agents_v1
 
     @property
-    def components_v1(self):
-        if not self._components_v1:
-            self._components_v1 = polyaxon_sdk.HubComponentsV1Api(self.api_client)
-        return self._components_v1
+    def component_hub_v1(self):
+        if not self._component_hub_v1:
+            self._component_hub_v1 = polyaxon_sdk.ComponentHubV1Api(self.api_client)
+        return self._component_hub_v1
 
     @property
-    def models_v1(self):
-        if not self._models_v1:
-            self._models_v1 = polyaxon_sdk.HubModelsV1Api(self.api_client)
-        return self._models_v1
+    def model_registry_v1(self):
+        if not self._model_registry_v1:
+            self._model_registry_v1 = polyaxon_sdk.ModelRegistryV1Api(self.api_client)
+        return self._model_registry_v1
 
     def sanitize_for_serialization(self, value):
         return self.api_client.sanitize_for_serialization(value)
