@@ -173,13 +173,15 @@ def _read_from_polyaxon_hub(hub: str):
     owner, component, version = get_component_info(hub)
 
     try:
-        config = None
         if owner == DEFAULT_HUB:
             config = ClientConfig()
-        response = PolyaxonClient(
-            config=config,
-            token=NO_AUTH,
-        ).component_hub_v1.get_component_version(owner, component, version)
+            client = PolyaxonClient(
+                config=config,
+                token=NO_AUTH,
+            )
+        else:
+            client = PolyaxonClient()
+        response = client.component_hub_v1.get_component_version(owner, component, version)
         return _read_from_stream(response.content)
     except (ApiException, HTTPError) as e:
         raise PolyaxonClientException(
