@@ -31,15 +31,15 @@ from polyaxon.cli.init import init
 from polyaxon.cli.operations import ops
 from polyaxon.cli.port_forward import port_forward
 from polyaxon.cli.projects import project
+from polyaxon.cli.registry import registry
 from polyaxon.cli.run import run
 from polyaxon.cli.session import set_versions_config
-from polyaxon.cli.upload import upload
 from polyaxon.cli.version import check_cli_version, upgrade, version
-from polyaxon.logger import configure_logger
+from polyaxon.logger import clean_outputs, configure_logger
 from polyaxon.utils.bool_utils import to_bool
+from polyaxon.utils.formatting import Printer
 
 DOCS_GEN = to_bool(os.environ.get("POLYAXON_DOCS_GEN", False))
-
 click_completion.init()
 
 
@@ -55,6 +55,7 @@ click_completion.init()
     "Currently used for run command in --local mode.",
 )
 @click.pass_context
+@clean_outputs
 def cli(context, verbose, offline):
     """Polyaxon - Cloud Native Machine Learning Automation & Experimentation tool.
 
@@ -68,7 +69,7 @@ def cli(context, verbose, offline):
 
     This CLI tool comes with a caching mechanism:
 
-      - You can initialize a project with: polyaxon init [project name]
+      - You can initialize a project with: polyaxon init -p [project name]
 
       - Otherwise Polyaxon will the default global path will be used for the cache.
 
@@ -108,6 +109,17 @@ def cli(context, verbose, offline):
     """
     settings.set_cli_config()
     configure_logger(verbose)
+    if settings.CLIENT_CONFIG.no_op:
+        Printer.print_warning(
+            "POLYAXON_NO_OP is set to `true`, some commands will not function correctly."
+        )
+    context.obj = context.obj or {}
+    if not settings.CLIENT_CONFIG.client_header:
+        settings.CLIENT_CONFIG.set_cli_header()
+    context.obj["offline"] = offline
+    if offline:
+        os.environ["POLYAXON_IS_OFFLINE"] = "true"
+        settings.CLIENT_CONFIG.is_offline = True
     non_check_cmds = [
         "completion",
         "config",
@@ -125,24 +137,21 @@ def cli(context, verbose, offline):
         "upgrade",
         "port-forward",
     ]
-    context.obj = context.obj or {}
-    if not settings.CLIENT_CONFIG.client_header:
-        settings.CLIENT_CONFIG.set_cli_header()
-    context.obj["offline"] = offline
-    if offline:
-        os.environ["POLYAXON_IS_OFFLINE"] = "true"
-        settings.CLIENT_CONFIG.is_offline = True
-    if not (
-        context.invoked_subcommand in non_check_cmds
-        or offline
-        or settings.CLIENT_CONFIG.no_api
-        or settings.CLIENT_CONFIG.is_ops
-        or DOCS_GEN
-    ) and settings.CLI_CONFIG.should_check(
-        settings.CLIENT_CONFIG.compatibility_check_interval
+    if not settings.CLI_CONFIG.installation:
+        pass
+    if (
+        not (
+            context.invoked_subcommand in non_check_cmds
+            or offline
+            or settings.CLIENT_CONFIG.no_api
+            or settings.CLIENT_CONFIG.is_ops
+            or DOCS_GEN
+        )
+        and not settings.CLI_CONFIG.installation
     ):
-        cli_config = set_versions_config()
-        check_cli_version(cli_config)
+        cli_config = set_versions_config(is_cli=False)
+        settings.CLI_CONFIG = cli_config
+        check_cli_version(cli_config, is_cli=False)
 
 
 cli.add_command(login)
@@ -156,15 +165,16 @@ cli.add_command(init)
 cli.add_command(project)
 cli.add_command(ops)
 cli.add_command(hub)
+cli.add_command(registry)
 cli.add_command(run)
 cli.add_command(dashboard)
 cli.add_command(admin)
 cli.add_command(port_forward)
 cli.add_command(completion)
-cli.add_command(upload)
 if settings.CLIENT_CONFIG.is_ops:
 
     from polyaxon.cli.components.agent import agent
+    from polyaxon.cli.components.clean_artifacts import clean_artifacts
     from polyaxon.cli.components.clean_ops import clean_ops
     from polyaxon.cli.components.docker import docker
     from polyaxon.cli.components.initializer import initializer
@@ -172,8 +182,10 @@ if settings.CLIENT_CONFIG.is_ops:
     from polyaxon.cli.components.proxies import proxy
     from polyaxon.cli.components.sidecar import sidecar
     from polyaxon.cli.components.tuner import tuner
+    from polyaxon.cli.components.wait import wait
 
     cli.add_command(agent)
+    cli.add_command(clean_artifacts)
     cli.add_command(clean_ops)
     cli.add_command(docker)
     cli.add_command(initializer)
@@ -181,3 +193,4 @@ if settings.CLIENT_CONFIG.is_ops:
     cli.add_command(proxy)
     cli.add_command(sidecar)
     cli.add_command(tuner)
+    cli.add_command(wait)
