@@ -22,7 +22,7 @@ from polyaxon.exceptions import PolyaxonNotificationException
 from polyaxon.logger import logger
 from polyaxon.notifiers.spec import NotificationSpec
 from polyaxon.parser import parser
-from polyaxon.utils.http_utils import add_notification_referrer_param
+from polyaxon.utils.http_utils import add_notification_referrer_param, clean_host
 from polyaxon.utils.list_utils import to_list
 from polyaxon.utils.urls_utils import validate_url
 
@@ -39,9 +39,15 @@ class BaseNotifier:
     validate_keys = None
 
     @staticmethod
-    def get_url():
+    def get_url(notification: NotificationSpec):
+        run_path = notification.get_url_path()
+        if not run_path:
+            return
+        url = "{}/{}".format(clean_host(settings.CLIENT_CONFIG.host), run_path)
         return add_notification_referrer_param(
-            settings.CLIENT_CONFIG.host, provider="polyaxon", is_absolute=False
+            url,
+            provider="polyaxon",
+            is_absolute=False,
         )
 
     @classmethod
@@ -117,7 +123,7 @@ class BaseNotifier:
     def _prepare(cls, context: Dict) -> Dict:
         """This is where you should alter the context to fit the action.
 
-        Default behaviour will leave the context as it is.
+        Default behavior will leave the context as it is.
         """
         if not context and cls.raise_empty_context:
             raise PolyaxonNotificationException(
@@ -136,7 +142,9 @@ class BaseNotifier:
 
     @classmethod
     def execute(
-        cls, notification: NotificationSpec, config: Optional[ConfigType] = None,
+        cls,
+        notification: NotificationSpec,
+        config: Optional[ConfigType] = None,
     ) -> Any:
         if not notification:
             raise PolyaxonNotificationException(
