@@ -15,13 +15,11 @@
 # limitations under the License.
 
 import ast
-import copy
 import jinja2
 
 from collections.abc import Mapping
 from typing import Dict
 
-from polyaxon.config_reader.utils import deep_update
 from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.polyaxonfile.specs.libs.engine import get_engine
 from polyaxon.polyaxonfile.specs.sections import Sections
@@ -54,12 +52,22 @@ class Parser:
 
         return cls._get_section_data(section_data)
 
+    @staticmethod
+    def get_parsed_params(param_spec: Dict[str, ParamSpec]) -> Dict:
+        parsed_params = {"params": {}}
+        for param in param_spec or {}:
+            parsed_params[param] = param_spec[param].get_display_value()
+            # Add params level
+            if not param_spec[param].is_context:
+                parsed_params["params"][param] = param_spec[param].to_parsed_param()
+
+        return parsed_params
+
     @classmethod
     def parse(
         cls, config, param_spec: Dict[str, ParamSpec]
     ):  # pylint:disable=too-many-branches
-        param_spec = param_spec or {}
-        parsed_params = {param: param_spec[param].display_value for param in param_spec}
+        parsed_params = cls.get_parsed_params(param_spec)
 
         parsed_data = {Sections.VERSION: config.version, Sections.KIND: config.kind}
 
@@ -69,13 +77,20 @@ class Parser:
             parsed_data[Sections.DESCRIPTION] = config.description
         if config.tags:
             parsed_data[Sections.TAGS] = config.tags
+        contexts = getattr(config, Sections.CONTEXTS)
+        if contexts:
+            parsed_data[Sections.CONTEXTS] = [
+                cls.parse_io(io.to_dict(), parsed_params) for io in contexts
+            ]
         inputs = getattr(config, Sections.INPUTS)
         if inputs:
-            parsed_data[Sections.INPUTS] = [io.to_dict() for io in inputs]
+            parsed_data[Sections.INPUTS] = [
+                cls.parse_io(io.to_dict(), parsed_params) for io in inputs
+            ]
         outputs = getattr(config, Sections.OUTPUTS)
         if outputs:
             parsed_data[Sections.OUTPUTS] = [
-                cls.parse_expression(io.to_dict(), parsed_params) for io in outputs
+                cls.parse_io(io.to_dict(), parsed_params) for io in outputs
             ]
 
         # Check workflow
@@ -84,9 +99,6 @@ class Parser:
             parsed_data[Sections.MATRIX] = cls.parse_expression(
                 matrix_section, parsed_params
             )
-            matrix_params = copy.copy(parsed_data[Sections.MATRIX])
-            if matrix_params:
-                parsed_params = deep_update(matrix_params, parsed_params)
 
         for section in Sections.PARSING_SECTIONS:
             config_section = cls._get_section(config, section)
@@ -102,6 +114,10 @@ class Parser:
                     config_section, parsed_params
                 )
 
+        if Sections.CONDITIONS in parsed_data and not isinstance(
+            parsed_data[Sections.CONDITIONS], str
+        ):
+            parsed_data[Sections.CONDITIONS] = str(parsed_data[Sections.CONDITIONS])
         config_section = cls._get_section(config, Sections.RUN)
         if config_section:
             parsed_data[Sections.RUN] = config_section
@@ -138,15 +154,26 @@ class Parser:
     def parse_section(
         cls, config_section, param_spec: Dict[str, ParamSpec], parse_params: bool = True
     ):
-        param_spec = param_spec or {}
         if parse_params:
-            param_spec = {
-                param: param_spec[param].display_value for param in param_spec
-            }
+            param_spec = cls.get_parsed_params(param_spec)
         if config_section:
             return cls.parse_expression(config_section, param_spec)
         return config_section
 
+    @classmethod
+    def parse_io(
+        cls,
+        expression: Dict,
+        params: Dict[str, ParamSpec],
+        check_operators: bool = False,
+    ):
+        # Arg format should not be converted
+        arg_format = expression.pop("argFormat", None)
+        value = cls.parse_expression(expression, params, check_operators)
+        if arg_format:
+            value["argFormat"] = arg_format
+        return value
+
     @classmethod
     def parse_expression(  # pylint:disable=too-many-branches
         cls, expression, params: Dict, check_operators: bool = False
