@@ -19,16 +19,17 @@ import polyaxon_sdk
 from marshmallow import fields, validate
 
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
+from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
-from polyaxon.polyflow.matrix.params import MatrixSchema
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.polyflow.matrix.params import HpParamSchema
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
 
 
 class RandomSearchSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.RANDOM))
     params = fields.Dict(
-        keys=fields.Str(), values=fields.Nested(MatrixSchema), required=True
+        keys=fields.Str(), values=fields.Nested(HpParamSchema), required=True
     )
     num_runs = RefOrObject(
         fields.Int(required=True, validate=validate.Range(min=1)), required=True
@@ -42,7 +43,7 @@ class RandomSearchSchema(BaseCamelSchema):
         return V1RandomSearch
 
 
-class V1RandomSearch(BaseConfig, polyaxon_sdk.V1RandomSearch):
+class V1RandomSearch(BaseSearchConfig, polyaxon_sdk.V1RandomSearch):
     """Random search creates a number of unique experiments by sampling randomly
     from a search space.
     Random search is a competitive method for black-box parameter tuning in machine learning.
