@@ -23,12 +23,12 @@ from polyaxon.connections.reader import (
     get_connection_schema_env_name,
 )
 from polyaxon.env_vars.keys import (
-    POLYAXON_KEYS_API_HOST,
     POLYAXON_KEYS_API_VERSION,
     POLYAXON_KEYS_AUTH_TOKEN,
     POLYAXON_KEYS_AUTHENTICATION_TYPE,
     POLYAXON_KEYS_HEADER,
     POLYAXON_KEYS_HEADER_SERVICE,
+    POLYAXON_KEYS_HOST,
     POLYAXON_KEYS_IS_MANAGED,
     POLYAXON_KEYS_K8S_NAMESPACE,
     POLYAXON_KEYS_K8S_NODE_NAME,
@@ -218,6 +218,18 @@ def get_env_from_k8s_resources(
     return env_vars
 
 
+def get_base_env_vars():
+    return [
+        get_from_field_ref(
+            name=POLYAXON_KEYS_K8S_NODE_NAME, field_path="spec.nodeName"
+        ),
+        get_from_field_ref(
+            name=POLYAXON_KEYS_K8S_NAMESPACE, field_path="metadata.namespace"
+        ),
+        get_from_field_ref(name=POLYAXON_KEYS_K8S_POD_ID, field_path="metadata.name"),
+    ]
+
+
 def get_service_env_vars(
     header: str,
     service_header: str,
@@ -231,18 +243,10 @@ def get_service_env_vars(
     api_version: str,
     run_instance: str,
 ) -> List[k8s_schemas.V1EnvVar]:
-    env_vars = [
-        get_env_var(name=POLYAXON_KEYS_API_HOST, value=api_host),
+    env_vars = get_base_env_vars() + [
+        get_env_var(name=POLYAXON_KEYS_HOST, value=api_host),
         get_env_var(name=POLYAXON_KEYS_IS_MANAGED, value=True),
         get_env_var(name=POLYAXON_KEYS_API_VERSION, value=api_version),
-        # Pod info
-        get_from_field_ref(
-            name=POLYAXON_KEYS_K8S_NODE_NAME, field_path="spec.nodeName"
-        ),
-        get_from_field_ref(
-            name=POLYAXON_KEYS_K8S_NAMESPACE, field_path="metadata.namespace"
-        ),
-        get_from_field_ref(name=POLYAXON_KEYS_K8S_POD_ID, field_path="metadata.name"),
         get_run_instance_env_var(run_instance),
     ]
     if header:
