@@ -17,12 +17,7 @@
 from typing import Dict, Iterable, Optional
 
 from polyaxon import pkg
-from polyaxon.polyflow import (  # noqa
-    V1CompiledOperation,
-    V1KFReplica,
-    V1Plugins,
-    V1TFJob,
-)
+from polyaxon.polyflow import V1CompiledOperation, V1KFReplica, V1Plugins, V1TFJob
 from polyaxon.polypod.compiler.converters import BaseConverter
 from polyaxon.polypod.compiler.converters.base import PlatformConverterMixin
 from polyaxon.polypod.custom_resources import get_tf_job_custom_resource
@@ -40,6 +35,7 @@ class TfJobConverter(TFJobMixin, BaseConverter):
         connection_by_names: Dict[str, V1ConnectionType],
         secrets: Optional[Iterable[V1K8sResourceType]],
         config_maps: Optional[Iterable[V1K8sResourceType]],
+        default_sa: str = None,
         default_auth: bool = False,
     ) -> Dict:
         job = compiled_operation.run  # type: V1TFJob
@@ -60,6 +56,7 @@ class TfJobConverter(TFJobMixin, BaseConverter):
                 connection_by_names=connection_by_names,
                 secrets=secrets,
                 config_maps=config_maps,
+                default_sa=default_sa,
                 num_replicas=replica.replicas,
             )
 
@@ -84,6 +81,7 @@ class TfJobConverter(TFJobMixin, BaseConverter):
             sync_statuses=contexts.sync_statuses,
             notifications=plugins.notifications,
             labels=labels,
+            annotations=self.annotations,
         )
 
 
