@@ -16,6 +16,8 @@
 
 import itertools
 
+from typing import Dict, List
+
 from polyaxon.polyflow import V1GridSearch
 from polyaxon.polytune.matrix.utils import to_numpy
 from polyaxon.polytune.search_managers.base import BaseManager
@@ -26,7 +28,7 @@ class GridSearchManager(BaseManager):
 
     CONFIG = V1GridSearch
 
-    def get_suggestions(self):
+    def get_suggestions(self, params: List[Dict] = None) -> List[Dict]:
         suggestions = []
         keys = list(self.config.params.keys())
         values = [to_numpy(v) for v in self.config.params.values()]
