@@ -15,21 +15,25 @@
 # limitations under the License.
 
 from polyaxon import settings
+from polyaxon.proxies.schemas.base import clean_config
 from polyaxon.proxies.schemas.buffering import get_buffering_config
 from polyaxon.proxies.schemas.charset import get_charset_config
 from polyaxon.proxies.schemas.error_page import get_error_page_config
+from polyaxon.proxies.schemas.favicon import get_favicon_config
 from polyaxon.proxies.schemas.gateway.api import get_api_location_config
 from polyaxon.proxies.schemas.gateway.auth import (
     get_auth_config,
     get_auth_location_config,
 )
 from polyaxon.proxies.schemas.gateway.dns import get_resolver
+from polyaxon.proxies.schemas.gateway.healthz import get_healthz_location_config
 from polyaxon.proxies.schemas.gateway.services import get_services_location_config
 from polyaxon.proxies.schemas.gateway.ssl import get_ssl_config
 from polyaxon.proxies.schemas.gateway.streams import get_streams_location_config
 from polyaxon.proxies.schemas.gzip import get_gzip_config
 from polyaxon.proxies.schemas.listen import get_listen_config
 from polyaxon.proxies.schemas.logging import get_logging_config
+from polyaxon.proxies.schemas.robots import get_robots_config
 from polyaxon.proxies.schemas.timeout import get_timeout_config
 
 
@@ -46,6 +50,9 @@ def get_base_config():
         get_buffering_config(),
         get_timeout_config(),
         get_error_page_config(),
+        get_robots_config(),
+        get_favicon_config(),
+        get_healthz_location_config(),
         get_auth_location_config(resolver=resolver),
         get_streams_location_config(resolver=resolver, auth=auth),
         get_services_location_config(resolver=resolver, auth=auth, rewrite=False),
@@ -54,4 +61,4 @@ def get_base_config():
     ]
     # config += get_plugins_location_config(resolver=resolver, auth=auth)
 
-    return "\n".join(config)
+    return clean_config(config)
