@@ -19,6 +19,8 @@ import os
 import sys
 import time
 
+from typing import Dict, List
+
 import polyaxon_sdk
 import ujson
 
@@ -37,12 +39,13 @@ from polyaxon.env_vars.getters import (
     get_collect_resources,
     get_log_level,
 )
-from polyaxon.polyboard.artifacts import V1ArtifactKind
+from polyaxon.logger import logger
+from polyaxon.polyboard.artifacts import V1ArtifactKind, V1RunArtifact
 from polyaxon.polyboard.events import LoggedEventSpec, V1Event, get_asset_path
-from polyaxon.tracking.events import EventFileWriter, events_processors
-from polyaxon.tracking.events.writer import ResourceFileWriter
+from polyaxon.polyboard.processors import events_processors
+from polyaxon.polyboard.processors.writer import EventFileWriter, ResourceFileWriter
 from polyaxon.utils.env import get_run_env
-from polyaxon.utils.path_utils import get_path_extension
+from polyaxon.utils.path_utils import get_base_filename, get_path_extension
 
 TEMP_RUN_ARTIFACTS = "/tmp/.plxartifacts"
 
@@ -102,12 +105,16 @@ class Run(RunClient):
         artifacts_path: str = None,
     ):
         super().__init__(
-            owner=owner, project=project, run_uuid=run_uuid, client=client,
+            owner=owner,
+            project=project,
+            run_uuid=run_uuid,
+            client=client,
         )
         self.track_code = track_code
         self.track_env = track_env
         self._has_model = False
         self._has_events = False
+        self._has_metrics = False
         self._has_tensorboard = False
         self._artifacts_path = None
         self._outputs_path = None
@@ -146,12 +153,23 @@ class Run(RunClient):
         if settings.CLIENT_CONFIG.is_managed:
             self._register_wait()
 
-    @property
-    def is_service(self):
-        if settings.CLIENT_CONFIG.no_op:
-            return None
+    def _add_event(self, event: LoggedEventSpec):
+        if self._event_logger:
+            self._event_logger.add_event(event)
+        else:
+            logger.warning(
+                "Could not log event {}, "
+                "the event logger was not configured properly".format(event.name)
+            )
 
-        return settings.CLIENT_CONFIG.is_managed and settings.CLIENT_CONFIG.is_service
+    def _add_events(self, events: List[LoggedEventSpec]):
+        if self._event_logger:
+            self._event_logger.add_events(events)
+        else:
+            logger.warning(
+                "Could not log events {}, "
+                "the event logger was not configured properly".format(len(events))
+            )
 
     @check_no_op
     def get_artifacts_path(self):
@@ -171,18 +189,8 @@ class Run(RunClient):
 
     @check_no_op
     def get_model_path(self, rel_path: str = "model"):
-        """Returns a model path for this run relative to the outputs path.
-
-        Args:
-             rel_path: str, optional, default "model",
-                       the relative path to the `outputs` context.
-        Returns:
-            str, outputs_path / rel_path
-        """
-        path = self._outputs_path
-        if rel_path:
-            path = os.path.join(path, rel_path)
-        return path
+        """Do not use"""
+        return "/tmp/{}".format(rel_path)
 
     @check_no_op
     @check_offline
@@ -194,7 +202,7 @@ class Run(RunClient):
              rel_path: str, optional, default "tensorboard",
                        the relative path to the `outputs` context.
         Returns:
-            str, outputs_path / rel_path
+            str, outputs_path/rel_path
         """
         path = self._outputs_path
         if rel_path:
@@ -257,12 +265,22 @@ class Run(RunClient):
     def _log_has_events(self):
         if not self._has_events:
             self._has_events = True
-            self._log_meta(has_events=True)
+            self.log_meta(has_events=True)
+
+    def _log_has_metrics(self):
+        data = {}
+        if not self._has_metrics:
+            data["has_metrics"] = True
+        if not self._has_events:
+            data["has_events"] = True
+        if data:
+            self._has_metrics = True
+            self.log_meta(**data)
 
     def _log_has_model(self):
         if not self._has_model:
             self._has_model = True
-            self._log_meta(has_model=True)
+            self.log_meta(has_model=True)
 
     @check_no_op
     @check_offline
@@ -284,7 +302,7 @@ class Run(RunClient):
             step: int, optional
             timestamp: datetime, optional
         """
-        self._log_has_events()
+        self._log_has_metrics()
 
         events = []
         event_value = events_processors.metric(value)
@@ -298,7 +316,7 @@ class Run(RunClient):
             )
         )
         if events:
-            self._event_logger.add_events(events)
+            self._add_events(events)
             self._results[name] = event_value
 
     @check_no_op
@@ -320,7 +338,7 @@ class Run(RunClient):
             timestamp: datetime, optional
             **metrics: **kwargs, key: value
         """
-        self._log_has_events()
+        self._log_has_metrics()
 
         events = []
         for metric in metrics:
@@ -337,7 +355,7 @@ class Run(RunClient):
                 )
             )
         if events:
-            self._event_logger.add_events(events)
+            self._add_events(events)
 
     @check_no_op
     @check_offline
@@ -358,13 +376,17 @@ class Run(RunClient):
         """
         self._log_has_events()
 
-        event_value = events_processors.roc_auc_curve(fpr=fpr, tpr=tpr, auc=auc,)
+        event_value = events_processors.roc_auc_curve(
+            fpr=fpr,
+            tpr=tpr,
+            auc=auc,
+        )
         logged_event = LoggedEventSpec(
             name=name,
             kind=V1ArtifactKind.CURVE,
             event=V1Event.make(timestamp=timestamp, step=step, curve=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -388,14 +410,15 @@ class Run(RunClient):
         self._log_has_events()
 
         event_value = events_processors.sklearn_roc_auc_curve(
-            y_preds=y_preds, y_targets=y_targets,
+            y_preds=y_preds,
+            y_targets=y_targets,
         )
         logged_event = LoggedEventSpec(
             name=name,
             kind=V1ArtifactKind.CURVE,
             event=V1Event.make(timestamp=timestamp, step=step, curve=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -419,14 +442,16 @@ class Run(RunClient):
         self._log_has_events()
 
         event_value = events_processors.pr_curve(
-            precision=precision, recall=recall, average_precision=average_precision,
+            precision=precision,
+            recall=recall,
+            average_precision=average_precision,
         )
         logged_event = LoggedEventSpec(
             name=name,
             kind=V1ArtifactKind.CURVE,
             event=V1Event.make(timestamp=timestamp, step=step, curve=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -448,14 +473,15 @@ class Run(RunClient):
         self._log_has_events()
 
         event_value = events_processors.sklearn_pr_curve(
-            y_preds=y_preds, y_targets=y_targets,
+            y_preds=y_preds,
+            y_targets=y_targets,
         )
         logged_event = LoggedEventSpec(
             name=name,
             kind=V1ArtifactKind.CURVE,
             event=V1Event.make(timestamp=timestamp, step=step, curve=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -477,13 +503,17 @@ class Run(RunClient):
         """
         self._log_has_events()
 
-        event_value = events_processors.curve(x=x, y=y, annotation=annotation,)
+        event_value = events_processors.curve(
+            x=x,
+            y=y,
+            annotation=annotation,
+        )
         logged_event = LoggedEventSpec(
             name=name,
             kind=V1ArtifactKind.CURVE,
             event=V1Event.make(timestamp=timestamp, step=step, curve=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -512,7 +542,7 @@ class Run(RunClient):
         is_file = isinstance(data, str) and os.path.exists(data)
         ext = "png"
         if is_file:
-            name = name or os.path.basename(data)
+            name = name or get_base_filename(data)
             ext = get_path_extension(filepath=data) or ext
         else:
             name = name or "image"
@@ -527,11 +557,15 @@ class Run(RunClient):
         asset_rel_path = os.path.relpath(asset_path, self._artifacts_path)
         if is_file:
             event_value = events_processors.image_path(
-                from_path=data, asset_path=asset_path
+                from_path=data,
+                asset_path=asset_path,
+                asset_rel_path=asset_rel_path,
             )
         elif hasattr(data, "encoded_image_string"):
             event_value = events_processors.encoded_image(
-                asset_path=asset_path, data=data, asset_rel_path=asset_rel_path,
+                asset_path=asset_path,
+                data=data,
+                asset_rel_path=asset_rel_path,
             )
         else:
             event_value = events_processors.image(
@@ -550,7 +584,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.IMAGE,
             event=V1Event.make(timestamp=timestamp, step=step, image=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -610,7 +644,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.IMAGE,
             event=V1Event.make(timestamp=timestamp, step=step, image=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -679,7 +713,7 @@ class Run(RunClient):
         is_file = isinstance(data, str) and os.path.exists(data)
         content_type = content_type or "gif"
         if is_file:
-            name = name or os.path.basename(data)
+            name = name or get_base_filename(data)
             content_type = get_path_extension(filepath=data) or content_type
         else:
             name = name or "video"
@@ -716,7 +750,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.VIDEO,
             event=V1Event.make(timestamp=timestamp, step=step, video=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -750,7 +784,7 @@ class Run(RunClient):
         is_file = isinstance(data, str) and os.path.exists(data)
         ext = content_type or "wav"
         if is_file:
-            name = name or os.path.basename(data)
+            name = name or get_base_filename(data)
             ext = get_path_extension(filepath=data) or ext
         else:
             name = name or "audio"
@@ -787,7 +821,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.AUDIO,
             event=V1Event.make(timestamp=timestamp, step=step, audio=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -812,7 +846,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.TEXT,
             event=V1Event.make(timestamp=timestamp, step=step, text=text),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -837,7 +871,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.HTML,
             event=V1Event.make(timestamp=timestamp, step=step, html=html),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -869,7 +903,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.HISTOGRAM,
             event=V1Event.make(timestamp=timestamp, step=step, histogram=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -905,7 +939,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.HISTOGRAM,
             event=V1Event.make(timestamp=timestamp, step=step, histogram=event_value),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -925,7 +959,7 @@ class Run(RunClient):
         """
         self._log_has_model()
 
-        name = name or os.path.basename(path)
+        name = name or get_base_filename(path)
         ext = None
         if os.path.isfile(path):
             ext = get_path_extension(filepath=path)
@@ -950,7 +984,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.MODEL,
             event=V1Event.make(timestamp=timestamp, step=step, model=model),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -969,7 +1003,7 @@ class Run(RunClient):
         """
         self._log_has_events()
 
-        name = name or os.path.basename(path)
+        name = name or get_base_filename(path)
         ext = get_path_extension(filepath=path)
 
         asset_path = get_asset_path(
@@ -991,7 +1025,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.DATAFRAME,
             event=V1Event.make(timestamp=timestamp, step=step, dataframe=df),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -1010,7 +1044,7 @@ class Run(RunClient):
         """
         self._log_has_events()
 
-        name = name or os.path.basename(name)
+        name = name or get_base_filename(path)
         ext = get_path_extension(filepath=path)
         artifact_kind = artifact_kind or V1ArtifactKind.FILE
 
@@ -1034,7 +1068,7 @@ class Run(RunClient):
             kind=artifact_kind,
             event=V1Event.make(timestamp=timestamp, step=step, artifact=artifact),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -1056,7 +1090,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.CHART,
             event=V1Event.make(timestamp=timestamp, step=step, chart=chart),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -1078,7 +1112,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.CHART,
             event=V1Event.make(timestamp=timestamp, step=step, chart=chart),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -1100,7 +1134,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.CHART,
             event=V1Event.make(timestamp=timestamp, step=step, chart=chart),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     @check_offline
@@ -1122,7 +1156,7 @@ class Run(RunClient):
             kind=V1ArtifactKind.CHART,
             event=V1Event.make(timestamp=timestamp, step=step, chart=chart),
         )
-        self._event_logger.add_event(logged_event)
+        self._add_event(logged_event)
 
     @check_no_op
     def get_log_level(self):
@@ -1166,11 +1200,35 @@ class Run(RunClient):
     @check_no_op
     @check_offline
     @can_log_outputs
-    def log_env(self):
+    def log_env(self, rel_path: str = None, content: Dict = None):
         """Logs information about the environment.
 
         Called automatically if track_env is set to True.
+
+        Can be called manually, and can accept a custom content as a form of a dictionary.
+
+        Args:
+            rel_path: str, optional, default "env.json".
+            content: Dict, optional, default to current system information.
         """
-        env_data = get_run_env()
-        with open(os.path.join(self._outputs_path, "env.json"), "w") as env_file:
-            env_file.write(ujson.dumps(env_data))
+        if not os.path.exists(self._outputs_path):
+            return
+        if not content:
+            content = get_run_env()
+
+        rel_path = rel_path or "env.json"
+        path = self._outputs_path
+        if rel_path:
+            path = os.path.join(path, rel_path)
+
+        with open(os.path.join(path), "w") as env_file:
+            env_file.write(ujson.dumps(content))
+
+        artifact_run = V1RunArtifact(
+            name="env",
+            kind=V1ArtifactKind.ENV,
+            path=self.get_rel_asset_path(path=path),
+            summary={"path": path},
+            is_input=False,
+        )
+        self.log_artifact_lineage(body=artifact_run)
