@@ -15,7 +15,6 @@
 # limitations under the License.
 
 from marshmallow.exceptions import ValidationError
-from tests.utils import BaseTestCase
 
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.connections.schemas import (
@@ -26,6 +25,7 @@ from polyaxon.connections.schemas import (
     V1HostPathConnection,
     validate_connection,
 )
+from tests.utils import BaseTestCase
 
 
 class TestV1BucketConnection(BaseTestCase):
@@ -146,6 +146,14 @@ class TestV1GitConnection(BaseTestCase):
         config = V1GitConnection.from_dict(config_dict)
         assert config.to_dict() == config_dict
 
+        config_dict = {
+            "url": "foo",
+            "revision": "foo",
+            "flags": ["flag1", "--flag2", "k=v"],
+        }
+        config = V1GitConnection.from_dict(config_dict)
+        assert config.to_dict() == config_dict
+
         with self.assertRaises(ValidationError):
             validate_connection(V1ConnectionKind.REGISTRY, config_dict)
 
