@@ -15,14 +15,14 @@
 # limitations under the License.
 
 import os
-
 import pytest
 
+from mock import MagicMock, patch
+
 from marshmallow import ValidationError
-from mock import patch
-from tests.utils import BaseTestCase
 
 from polyaxon import pkg
+from polyaxon.env_vars.keys import POLYAXON_KEYS_USE_GIT_REGISTRY
 from polyaxon.exceptions import PolyaxonfileError
 from polyaxon.polyaxonfile import check_polyaxonfile
 from polyaxon.polyaxonfile.specs import (
@@ -40,6 +40,7 @@ from polyaxon.polyflow.matrix import (
 )
 from polyaxon.polyflow.matrix.params import V1HpChoice, V1HpLinSpace
 from polyaxon.polyflow.termination import V1Termination
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polyaxonfile_mark
@@ -88,7 +89,8 @@ class TestPolyaxonfiles(BaseTestCase):
         with self.assertRaises(PolyaxonfileError):
             check_polyaxonfile(hub="component:12", is_cli=False, to_op=False)
 
-    def test_from_public_hub(self):
+    def test_from_git_hub(self):
+        os.environ[POLYAXON_KEYS_USE_GIT_REGISTRY] = "true"
         with patch("polyaxon.config_reader.spec._read_from_public_hub") as request_mock:
             request_mock.return_value = os.path.abspath(
                 "tests/fixtures/plain/simple_job.yml"
@@ -98,9 +100,31 @@ class TestPolyaxonfiles(BaseTestCase):
         assert request_mock.call_count == 1
         assert operation.kind == "operation"
         assert operation.hub_ref == "component:12"
+        del os.environ[POLYAXON_KEYS_USE_GIT_REGISTRY]
+
+    def test_from_public_hub(self):
+        with patch(
+            "polyaxon_sdk.ComponentHubV1Api.get_component_version"
+        ) as request_mock:
+            request_mock.return_value = MagicMock(
+                content=os.path.abspath("tests/fixtures/plain/simple_job.yml"),
+            )
+            operation = check_polyaxonfile(hub="component:12", is_cli=False, to_op=True)
+
+        assert request_mock.call_count == 1
+        assert operation.kind == "operation"
+        assert operation.hub_ref == "component:12"
 
     def test_from_hub(self):
-        operation = check_polyaxonfile(hub="org/component:12", is_cli=False, to_op=True)
+        with patch(
+            "polyaxon_sdk.ComponentHubV1Api.get_component_version"
+        ) as request_mock:
+            request_mock.return_value = MagicMock(
+                content=os.path.abspath("tests/fixtures/plain/simple_job.yml"),
+            )
+            operation = check_polyaxonfile(
+                hub="org/component:12", is_cli=False, to_op=True
+            )
         assert operation.version == pkg.SCHEMA_VERSION
         assert operation.kind == "operation"
         assert operation.hub_ref == "org/component:12"
@@ -494,3 +518,81 @@ class TestPolyaxonfiles(BaseTestCase):
         run_config = V1CompiledOperation.read(run_config.to_dict())
         run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
         assert run_config.run.to_dict() == expected_run
+
+    def test_specification_with_context_requirement(self):
+        contexts = {
+            "globals": {
+                "owner_name": "user",
+                "project_name": "project",
+                "project_unique_name": "user.project",
+                "project_uuid": "uuid",
+                "run_info": "user.project.runs.uuid",
+                "name": "run",
+                "uuid": "uuid",
+                "context_path": "/plx-context",
+                "artifacts_path": "/plx-context/artifacts",
+                "run_artifacts_path": "/plx-context/artifacts/test",
+                "run_outputs_path": "/plx-context/artifacts/test/outputs",
+                "namespace": "test",
+                "iteration": 12,
+                "ports": [1212, 1234],
+                "base_url": "/services/v1/test/user/project/runs/uuid",
+                "created_at": None,
+                "compiled_at": None,
+                "cloning_kind": None,
+                "original_uuid": None,
+            },
+            "init": {},
+            "connections": {"foo": {"key": "connection-value"}},
+        }
+        run_config = CompiledOperationSpecification.read(
+            [
+                os.path.abspath(
+                    "tests/fixtures/plain/polyaxonfile_with_contexts_requirements.yaml"
+                ),
+                {"kind": "compiled_operation"},
+            ]
+        )
+
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
+        expected_run = {
+            "kind": V1RunKind.JOB,
+            "init": [
+                {
+                    "artifacts": {"files": ["{{globals.run_outputs_path}}/foo"]},
+                    "connection": "{{connections['foo']['key']}}",
+                }
+            ],
+            "container": {
+                "image": "continuumio/miniconda3",
+                "command": ["python"],
+                "workingDir": "{{ globals.artifacts_path }}/polyaxon-quick-start",
+                "args": ["-c \"print('Tweet tweet')\""],
+                "name": "polyaxon-main",
+            },
+        }
+        assert run_config.run.to_dict() == expected_run
+        run_config = V1CompiledOperation.read(run_config.to_dict())
+        run_config = CompiledOperationSpecification.apply_operation_contexts(run_config)
+        assert run_config.run.to_dict() == expected_run
+
+        expected_run = {
+            "kind": V1RunKind.JOB,
+            "init": [
+                {
+                    "artifacts": {"files": ["/plx-context/artifacts/test/outputs/foo"]},
+                    "connection": "connection-value",
+                }
+            ],
+            "container": {
+                "image": "continuumio/miniconda3",
+                "command": ["python"],
+                "workingDir": "/plx-context/artifacts/polyaxon-quick-start",
+                "args": ["-c \"print('Tweet tweet')\""],
+                "name": "polyaxon-main",
+            },
+        }
+        run_config = CompiledOperationSpecification.apply_runtime_contexts(
+            run_config, contexts=contexts
+        )
+        assert run_config.run.to_dict() == expected_run
