@@ -13,15 +13,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from tests.utils import BaseTestCase
-
 from polyaxon.k8s import k8s_schemas
 from polyaxon.k8s.custom_resources.crd import get_custom_object
-from polyaxon.polyflow import V1Notification, V1NotificationTrigger
+from polyaxon.lifecycle import V1Statuses
+from polyaxon.polyflow import V1Notification
 from polyaxon.polyflow.environment import V1Environment
 from polyaxon.polyflow.termination import V1Termination
 from polyaxon.polypod.custom_resources import get_service_custom_resource
 from polyaxon.polypod.pod.spec import get_pod_spec, get_pod_template_spec
+from tests.utils import BaseTestCase
 
 
 class TestServiceCRD(BaseTestCase):
@@ -63,6 +63,7 @@ class TestServiceCRD(BaseTestCase):
             api_version="core.polyaxon.com/v1",
             labels={"foo": "bar"},
             custom_object=custom_object,
+            annotations={"foo": "long-foo-bar" * 300},
         )
 
         crd = get_service_custom_resource(
@@ -75,6 +76,7 @@ class TestServiceCRD(BaseTestCase):
             termination=termination,
             environment=environment,
             labels=environment.labels,
+            annotations={"foo": "long-foo-bar" * 300},
             collect_logs=True,
             sync_statuses=True,
             notifications=None,
@@ -95,9 +97,7 @@ class TestServiceCRD(BaseTestCase):
             environment=None,
             labels=None,
         )
-        notifications = [
-            V1Notification(connections=["test"], trigger=V1NotificationTrigger.DONE)
-        ]
+        notifications = [V1Notification(connections=["test"], trigger=V1Statuses.DONE)]
         custom_object = {
             "template": get_pod_template_spec(metadata=metadata, pod_spec=pod_spec),
             "ports": [12, 121, 12],
@@ -108,11 +108,12 @@ class TestServiceCRD(BaseTestCase):
             kind="Operation",
             api_version="core.polyaxon.com/v1",
             labels=None,
+            annotations=None,
             custom_object={
                 "serviceSpec": custom_object,
                 "collectLogs": False,
                 "syncStatuses": False,
-                "notifications": [n.to_dict() for n in notifications],
+                "notifications": [n.to_operator() for n in notifications],
             },
         )
 
@@ -129,6 +130,7 @@ class TestServiceCRD(BaseTestCase):
             notifications=notifications,
             environment=None,
             labels=None,
+            annotations=None,
             ports=[12, 121, 12],
         )
 
