@@ -16,11 +16,9 @@
 
 import pytest
 
-from tests.utils import BaseTestCase
-
+from polyaxon.auxiliaries import V1PolyaxonInitContainer, get_init_resources
 from polyaxon.connections.kinds import V1ConnectionKind
 from polyaxon.connections.schemas import V1GitConnection
-from polyaxon.containers.containers import V1PolyaxonInitContainer, get_init_resources
 from polyaxon.containers.contexts import CONTEXT_MOUNT_ARTIFACTS
 from polyaxon.containers.names import INIT_GIT_CONTAINER_PREFIX, generate_container_name
 from polyaxon.exceptions import PolypodException
@@ -35,6 +33,7 @@ from polyaxon.polypod.common.volumes import get_volume_name
 from polyaxon.polypod.init.git import get_git_init_container, get_repo_context_args
 from polyaxon.polypod.specs.contexts import PluginsContextsSpec
 from polyaxon.schemas.types import V1ConnectionType
+from tests.utils import BaseTestCase
 
 
 @pytest.mark.polypod_mark
@@ -50,7 +49,7 @@ class TestInitGit(BaseTestCase):
             revision=None,
             mount_path="/somepath",
         )
-        assert args == ["--repo_path=/somepath/user/repo1", "--url=http://foo.com"]
+        assert args == ["--repo-path=/somepath/user/repo1", "--url=http://foo.com"]
 
     def test_get_repo_context_args(self):
         args = get_repo_context_args(
@@ -60,7 +59,7 @@ class TestInitGit(BaseTestCase):
             mount_path="/somepath",
         )
         assert args == [
-            "--repo_path=/somepath/user/repo1",
+            "--repo-path=/somepath/user/repo1",
             "--url=http://foo.com",
             "--revision=00b9d2ea01c40f58d6b4051319f9375675a43c02",
         ]
@@ -72,7 +71,7 @@ class TestInitGit(BaseTestCase):
             mount_path="/somepath",
         )
         assert args == [
-            "--repo_path=/somepath/user/repo1",
+            "--repo-path=/somepath/user/repo1",
             "--url=http://foo.com",
             "--revision=dev",
         ]
@@ -84,7 +83,7 @@ class TestInitGit(BaseTestCase):
             mount_path="/somepath",
         )
         assert args == [
-            "--repo_path=/somepath/user/repo1",
+            "--repo-path=/somepath/user/repo1",
             "--url=http://foo.com",
             "--revision=00b9d2ea01c40f58d6b4051319f9375675a43c02",
         ]
@@ -146,7 +145,7 @@ class TestInitGit(BaseTestCase):
         assert container.image_pull_policy == "IfNotPresent"
         assert container.command == ["polyaxon", "initializer", "git"]
         assert container.args == [
-            "--repo_path={}/{}".format(CONTEXT_MOUNT_ARTIFACTS, connection.name),
+            "--repo-path={}/{}".format(CONTEXT_MOUNT_ARTIFACTS, connection.name),
             "--url={}".format(connection.schema.url),
         ]
         assert container.resources == get_init_resources()
@@ -180,7 +179,7 @@ class TestInitGit(BaseTestCase):
         assert container.image_pull_policy == "IfNotPresent"
         assert container.command == ["polyaxon", "initializer", "git"]
         assert container.args == [
-            "--repo_path=/somepath/{}".format(connection.name),
+            "--repo-path=/somepath/{}".format(connection.name),
             "--url={}".format(connection.schema.url),
             "--revision=00b9d2ea01c40f58d6b4051319f9375675a43c02",
         ]
@@ -191,3 +190,40 @@ class TestInitGit(BaseTestCase):
             ),
             get_auth_context_mount(read_only=True),
         ]
+
+        connection = V1ConnectionType(
+            name="user/foo",
+            kind=V1ConnectionKind.GIT,
+            schema=V1GitConnection(
+                url="foo.com",
+                revision="00b9d2ea01c40f58d6b4051319f9375675a43c02",
+                flags=["--falg1", "--flag2=test", "k=v"],
+            ),
+        )
+        container = get_git_init_container(
+            polyaxon_init=V1PolyaxonInitContainer(
+                image="init/init", image_tag="", image_pull_policy="IfNotPresent"
+            ),
+            connection=connection,
+            mount_path="/somepath",
+            contexts=PluginsContextsSpec.from_config(V1Plugins(auth=True)),
+        )
+        assert container.name == generate_container_name(
+            INIT_GIT_CONTAINER_PREFIX, connection.name
+        )
+        assert container.image == "init/init"
+        assert container.image_pull_policy == "IfNotPresent"
+        assert container.command == ["polyaxon", "initializer", "git"]
+        assert container.args == [
+            "--repo-path=/somepath/{}".format(connection.name),
+            "--url={}".format(connection.schema.url),
+            "--revision=00b9d2ea01c40f58d6b4051319f9375675a43c02",
+            '--flags="--falg1 --flag2=test k=v"',
+        ]
+        assert container.resources == get_init_resources()
+        assert container.volume_mounts == [
+            get_connections_context_mount(
+                name=get_volume_name("/somepath"), mount_path="/somepath"
+            ),
+            get_auth_context_mount(read_only=True),
+        ]
